@@ -22,12 +22,17 @@
 #define RELEASE_LOCK(obj)
 #endif
 
+#ifdef __STDC_VERSION__
 #if __STDC_VERSION__ >= 199901L
 #include <stdbool.h>
+#endif
 #else
 #define bool    uint8_t
 #define true    1
 #define false   0
+#ifndef inline
+#define inline __inline__
+#endif
 #endif
 
 #if BUFSIZ < 1024
