@@ -231,13 +231,15 @@ override the specific value set by this preset level.\n\
 Preset level settings:\n\
 level\t lc\t lp\t dict\t\t pb\t mode\t mf\t fb\t mfc\n");
 	levelopts = PyString_FromString("%%d\t %u\t %u\t %u  \t %u\t %s\t %s\t %u\t %u\n");
-	for(int i = LZMA_BEST_COMPRESSION; i >= LZMA_BEST_SPEED; i--){
+	
+	{off_t i;
+	for(i = LZMA_BEST_COMPRESSION; i >= LZMA_BEST_SPEED; i--){
 		PyObject *settingsString = PyString_Format(levelopts, PyList_AsTuple(PyDict_Values(libLZMA_options_get(lzma_preset_lzma[i-1]))));
 		PyObject *levelNum = PyString_Format(settingsString, PyInt_FromLong(i));
 		PyString_Concat(&levelString,levelNum);
 		Py_DECREF(settingsString);
 		Py_DECREF(levelNum);
-	}
+	}}
 	Py_DECREF(levelopts);
 
 	libLZMAOptions_members[1] = MEMBER_DESCRIPTOR("level", T_OBJECT, level, PyString_AsString(levelString));
